@@ -16,7 +16,7 @@ use GD::Polygon;
 
 use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS $AUTOLOAD);
 
-$VERSION = '2.59';
+$VERSION = '2.60';
 our $XS_VERSION = $VERSION;
 $VERSION = eval $VERSION;
 
@@ -378,7 +378,7 @@ Images created by reading JPEG images will always be truecolor.  To
 force the image to be palette-based, pass a value of 0 in the optional
 $truecolor argument.
 
-=item B<$image = GD::Image-E<gt>newFromGif($file)>
+=item B<$image = GD::Image-E<gt>newFromGif($file, [$truecolor])>
 
 =item B<$image = GD::Image-E<gt>newFromGifData($data)>
 
@@ -390,7 +390,7 @@ Images created from GIFs are always 8-bit palette images. To convert
 to truecolor, you must create a truecolor image and then perform a
 copy.
 
-=item B<$image = GD::Image-E<gt>newFromXbm($file)>
+=item B<$image = GD::Image-E<gt>newFromXbm($file, [$truecolor])>
 
 This works in exactly the same way as C<newFromPng>, but reads the
 contents of an X Bitmap (black & white) file:
@@ -402,6 +402,18 @@ contents of an X Bitmap (black & white) file:
 There is no newFromXbmData() function, because there is no
 corresponding function in the gd library.
 
+=item B<$image = GD::Image-E<gt>newFromWBMP($file, [$truecolor])>
+
+This works in exactly the same way as C<newFromPng>, but reads the
+contents of an Windows BMP Bitmap file:
+
+	open (BMP,"coredump.bmp") || die;
+	$myImage = newFromWBMP GD::Image(\*BMP) || die;
+	close BMP;
+
+There is no newFromWBMPData() function, because there is no
+corresponding function in the gd library.
+
 =item B<$image = GD::Image-E<gt>newFromGd($file)>
 
 =item B<$image = GD::Image-E<gt>newFromGdData($data)>
@@ -580,7 +592,7 @@ color.  All other pixels will be considered background.
 =head2 Color Control
 
 These methods allow you to control and manipulate the GD::Image color
-table.
+table for palette, non-truecolor images.
 
 =over 4
 
@@ -647,8 +659,7 @@ red green and blue components specified. It uses a Hue/White/Black
 color representation to make the selected color more likely to match
 human perceptions of similar colors.
 
-If no colors have yet been
-allocated, then this call returns -1.
+If no colors have yet been allocated, then this call returns -1.
 
 Example:
 
